@@ -13,7 +13,7 @@ from rest_framework.exceptions import NotFound, ParseError
 
 from django.conf import settings
 
-from enterprise_data.utils import get_cache_key, update_session_with_enterprise_data
+from enterprise_data.utils import get_cache_key
 
 DEFAULT_REPORTING_CACHE_TIMEOUT = 60 * 60 * 6  # 6 hours (Value is in seconds)
 LOGGER = logging.getLogger('enterprise_data')
@@ -66,20 +66,25 @@ class EnterpriseApiClient(OAuthAPIClient):
 
         return data['results'][0]
 
-    def get_enterprise_customer(self, user, enterprise_id):
+    def get_enterprise_customer(self, enterprise_uuid):
         """
         Get the enterprises that this user has access to.
         """
+        LOGGER.info(f'[EnterpriseApiClient] getting latest info for enterprise customer:{enterprise_uuid}')
         cache_key = get_cache_key(
             resource='enterprise-customer',
-            user=user.username,
-            enterprise_customer=enterprise_id,
+            enterprise_customer=enterprise_uuid,
         )
         cached_response = TieredCache.get_cached_response(cache_key)
         if cached_response.is_found:
+            LOGGER.info(
+                f'[EnterpriseApiClient] cache info found for enterprise customer:{enterprise_uuid}'
+                f' with {cached_response.value}'
+            )
             return cached_response.value
 
-        url = urljoin(self.API_BASE_URL, 'enterprise-customer')
+        LOGGER.info(f'[EnterpriseApiClient] No cached info found for enterprise customer:{enterprise_uuid}')
+        url = urljoin(self.API_BASE_URL, f'enterprise-customer/{enterprise_uuid}')
 
         try:
             response = self.get(url)
@@ -88,42 +93,11 @@ class EnterpriseApiClient(OAuthAPIClient):
         except (HTTPError, RequestException) as exc:
             LOGGER.warning(
                 "[Data Overview Failure] Unable to retrieve Enterprise Customer details. "
-                f"User: {user.username}, Enterprise: {enterprise_id}, Exception: {exc}"
+                f"Enterprise: {enterprise_uuid}, Exception: {exc}"
             )
             raise
 
+        LOGGER.info(f'[EnterpriseApiClient] Setting cached for enterprise customer:{enterprise_uuid} with {data}')
         TieredCache.set_all_tiers(cache_key, data, DEFAULT_REPORTING_CACHE_TIMEOUT)
 
         return data
-
-    def get_enterprise_and_update_session(self, request):
-        """
-        Get the enterprise customer data and updates the session.
-
-        Returns:
-            Enterprise Customer or None if unable to get enterprise information
-        """
-        enterprise_id = request.parser_context.get('kwargs', {}).get('enterprise_id', '')
-        session = request.session
-        enterprise_data = None
-
-        audit_enrollment_check = enterprise_id not in session.get('enable_audit_data_reporting', {})
-        data_sharing_consent_check = enterprise_id not in session.get('enforce_data_sharing_consent', {})
-
-        if audit_enrollment_check or data_sharing_consent_check:
-            enterprise_data = self.get_enterprise_customer(request.user, enterprise_id)
-            enable_audit_data_reporting = False
-            enforce_data_sharing_consent = False
-
-            if enterprise_data:
-                enable_audit_data_reporting = enterprise_data.get('enable_audit_data_reporting', False)
-                enforce_data_sharing_consent = enterprise_data.get('enforce_data_sharing_consent', '')
-
-            update_session_with_enterprise_data(
-                request,
-                enterprise_id,
-                enable_audit_data_reporting=enable_audit_data_reporting,
-                enforce_data_sharing_consent=enforce_data_sharing_consent,
-            )
-
-        return enterprise_data
