@@ -5,9 +5,10 @@ Clients used to access third party systems.
 import os
 from datetime import datetime
 from functools import wraps
-from urllib.parse import parse_qs, urlparse
+from urllib.parse import parse_qs, urljoin, urlparse
+from edx_rest_api_client.client import get_oauth_access_token
 
-from edx_rest_api_client.client import EdxRestApiClient
+import requests
 
 
 class EdxOAuth2APIClient:
@@ -30,22 +31,13 @@ class EdxOAuth2APIClient:
         self.client_id = client_id or os.environ.get('LMS_OAUTH_KEY')
         self.client_secret = client_secret or os.environ.get('LMS_OAUTH_SECRET')
         self.expires_at = datetime.utcnow()
-        self.client = None
 
     def connect(self):
         """
         Connect to the REST API, authenticating with an access token retrieved with our client credentials.
         """
-        access_token, expires_at = EdxRestApiClient.get_oauth_access_token(
-            self.LMS_OAUTH_HOST + '/oauth2/access_token',
-            self.client_id,
-            self.client_secret,
-            'jwt'
-        )
-        self.client = EdxRestApiClient(
-            self.API_BASE_URL, append_slash=self.APPEND_SLASH, jwt=access_token,
-        )
-        self.expires_at = expires_at
+        url = urljoin(f'{self.LMS_OAUTH_HOST}/', 'oauth2/access_token')
+        self.access_token, self.expires_at = get_oauth_access_token(url, self.client_id, self.client_secret)
 
     def token_expired(self):
         """
@@ -68,6 +60,17 @@ class EdxOAuth2APIClient:
             return func(self, *args, **kwargs)
         return inner
 
+    def _requests(self, url, querystring):
+        headers = {'Authorization': "JWT {}".format(self.access_token)}
+        response = requests.get(
+            url,
+            headers=headers,
+            params=querystring
+        )
+        response.raise_for_status()
+        data = response.json()
+        return data
+
     def _load_data(
             self,
             resource,
@@ -93,45 +96,48 @@ class EdxOAuth2APIClient:
         """
         default_val = default if default is not self.DEFAULT_VALUE_SAFEGUARD else {}
         querystring = querystring or {}
+        path = resource
+        if resource_id:
+            path += '/' + resource_id
+        if detail_resource:
+            path += '/' + detail_resource
+
+        url = urljoin(f'{self.API_BASE_URL}/', path)
+        data = self._requests(url, querystring)
 
-        endpoint = getattr(self.client, resource)
-        endpoint = getattr(self.client, resource)(resource_id) if resource_id else endpoint
-        endpoint = getattr(endpoint, detail_resource) if detail_resource else endpoint
-        response = endpoint.get(**querystring)
         if should_traverse_pagination:
-            results = traverse_pagination(response, endpoint)
-            response = {
+            results = self.traverse_pagination(data, url)
+            data = {
                 'count': len(results),
                 'next': None,
                 'previous': None,
                 'results': results,
             }
 
-        return response or default_val
+        return data or default_val
 
+    def traverse_pagination(self, data, url):
+        """
+        Traverse a paginated API response.
 
-def traverse_pagination(response, endpoint):
-    """
-    Traverse a paginated API response.
+        Extracts and concatenates "results" (list of dict) returned by DRF-powered
+        APIs.
 
-    Extracts and concatenates "results" (list of dict) returned by DRF-powered
-    APIs.
+        Arguments:
+            data (Dict): Current response dict from service API
+            url (str): API endpoint path
 
-    Arguments:
-        response (Dict): Current response dict from service API
-        endpoint (slumber Resource object): slumber Resource object from edx-rest-api-client
+        Returns:
+            list of dict.
+        """
+        results = data.get('results', [])
 
-    Returns:
-        list of dict.
+        next_page = data.get('next')
+        while next_page:
+            querystring = parse_qs(urlparse(next_page).query, True)
+            request_data = self._requests(url, querystring)
 
-    """
-    results = response.get('results', [])
+            results += request_data.get('results', [])
+            next_page = request_data.get('next')
 
-    next_page = response.get('next')
-    while next_page:
-        querystring = parse_qs(urlparse(next_page).query, True)
-        response = endpoint.get(**querystring)
-        results += response.get('results', [])
-        next_page = response.get('next')
-
-    return results
+        return results
